using System;
using System.Collections.Generic;
using System.Text;

namespace Rainbird.AppServer.API
{
    /// <summary>
    /// Schnittstelle fr den Sperrungsdienst.
    /// </summary>
    public interface ILockingService
    {
        /// <summary>
        /// Fordert eine Sperre fr eine bestimmte Ressource an.
        /// </summary>
        /// <param name="resourceName">Name der zu sperrenden Ressource</param>
        /// <param name="key">Schlssel der zu sperrenden Ressource</param>
        /// <returns>Informationen ber die Sperre</returns>
        LockingInfo AcquireLock(string resourceName, string key);

        /// <summary>
        /// Gibt eine Sperre fr eine bestimmte Ressource wieder frei.
        /// </summary>
        /// <param name="resourceName">Name der zu sperrenden Ressource</param>
        /// <param name="key">Schlssel der zu sperrenden Ressource</param>
        void ReleaseLock(string resourceName, string key);

        /// <summary>
        /// Gibt eine Sperre mit einem bestimmten Schlssel wieder frei.
        /// </summary>        
        /// <param name="lockID">Sperrschlssel</param>
        void ReleaseLock(Guid lockID);

        /// <summary>
        /// Gibt Informationen ber eine bestehende Sperre einer bestimmten Ressource zurck.
        /// </summary>
        /// <param name="resourceName">Name der zu sperrenden Ressource</param>
        /// <param name="key">Schlssel der zu sperrenden Ressource</param>
        /// <returns>Informationen ber die Sperre</returns>
        LockingInfo GetLockInfo(string resourceName, string key);

        /// <summary>
        /// Gibt eine Auflistung aller aktuellen Sperren zurck.
        /// </summary>
        /// <returns>Liste mit Sperren</returns>
        IDictionary<Guid,LockingInfo> GetLockList();
    }
}
