using System;
using System.Collections.Generic;
using System.Text;
using System.Globalization;

namespace Rainbird.AppServer.API
{
    /// <summary>
    /// Schnittstelle des Sicherheitsdienstes.
    /// </summary>
    public interface ISecurityService
    {
        /// <summary>
        /// Gibt zurck, ob die aktuelle Sitzung gltig ist, oder nicht.
        /// </summary>
        bool IsSessionValid
        {
            get;
        }

        /// <summary>
        /// Meldet einen Benutzer am Applikationsserver an und erffnet eine neue Sitzung.
        /// </summary>        
        /// <returns>Sitzungsschlssel</returns>
        Guid Logon();

        /// <summary>
        /// Beendet eine Benutzersitzung.
        /// </summary>        
        void Logoff();

        /// <summary>
        /// Gibt die Liste der eingebauten Rollen zurck.
        /// </summary>
        IList<string> BuiltInRoles
        {
            get;
        }

        /// <summary>
        /// Erstellt eine neue Rolle.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <param name="windowsGroup">Windows-Gruppe</param>
        void CreateRole(string roleName, string windowsGroup);

        /// <summary>
        /// Lscht eine vorhandene Rolle.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        void DeleteRole(string roleName);

        /// <summary>
        /// Gibt die Windows-Gruppe einer Rolle zurck.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <returns>Windows-Gruppe</returns>
        string GetWindowsGroupFromRole(string roleName);

        /// <summary>
        /// Prft, ob der Aufrufer eine bestimmte Rolle hat, oder nicht.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <returns>Prfergebnis</returns>
        bool IsInRole(string roleName);

        /// <summary>
        /// Prft, ob eine bestimmte Rolle existiert.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <returns>Prfergebnis</returns>
        bool ExistRole(string roleName);

        /// <summary>
        /// Gibt eine Liste der Namen aller angelegten Rollen zurck.
        /// </summary>
        /// <returns>Liste mit Rollennamen</returns>
        IList<string> GetRoleNames();

        /// <summary>
        /// Prft, ob der Aufrufer vertrauenswrdig ist, oder nicht.
        /// </summary>
        /// <returns>Prfergebnis</returns>
        bool IsCallerTrustworthy
        {
            get;
        }
    }
}
