using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using System.Xml.Serialization;

namespace Rainbird.AppServer.API
{
    /// <summary>
    /// Beschreibt ein Datensperre auf dem Applikationsserver.
    /// </summary>
    [Serializable]
    [XmlRoot(ElementName="lockinginfo",Namespace="urn:Rainbird.AppServer.API.LockingInfo.2007")]
    public class LockingInfo
    {
        #region Deklarationen

        // Name der Ressource auf die sich die Sperre bezieht  
        [XmlElement(ElementName = "resourceName", IsNullable = false)]
        string _resourceName = string.Empty;

        // Eindeutiger Schlssel der Ressource auf die sich die Sperre bezieht
        [XmlElement(ElementName = "key", IsNullable = false)]
        string _key = string.Empty;

        // Schalter der angibt, ob der Benutzer die Sperre erhalten hat
        [XmlElement(ElementName = "success", IsNullable = false)]
        bool _success = false;

        // Zeitstempel der Sperre
        [XmlElement(ElementName = "timestamp", IsNullable = false)]
        DateTime _timestamp = DateTime.MinValue;

        // Eindeutiger Schlssel der Sperre
        [XmlElement(ElementName = "lockid", IsNullable = false)]
        Guid _lockID = Guid.Empty;

        // Benutzer der Sperre
        [XmlElement(ElementName = "username", IsNullable = false)]
        string _userName = string.Empty;

        // Nachricht vom Applikationsserver
        [XmlElement(ElementName = "message", IsNullable = false)]
        string _message = string.Empty;

        #endregion

        #region Konstruktoren

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="lockID">Schlssel der Sperre</param>
        /// <param name="resourceName">Name der zu sperrenden Datenquelle</param>
        /// <param name="key">Schlssel der zu sperrenden Daten</param>
        /// <param name="userName">Benutzername im Format "Domne\Benutzer"</param>
        /// <param name="timestamp">Zeitstempel der Sperre</param>
        /// <param name="success">Schalte fr erfolgreiche Sperrung</param>
        /// <param name="message">Nachricht vom Applikationsserver</param>
        public LockingInfo(Guid lockID, string resourceName, string key, string userName, DateTime timestamp, bool success,string message)
        { 
            // Werte bernehmen
            _lockID = lockID;
            _resourceName = resourceName;
            _key = key;
            _userName = userName;
            _timestamp = timestamp;
            _success = success;
            _message = message;
        }

        #endregion

        #region Eigenschaften der Sperre

        /// <summary>
        /// Gibt den Namen der Ressource, auf die sich die Sperre bezieht, zurck.
        /// </summary>
        public string ResourceName
        {
            get { return _resourceName; }            
        }
        
        /// <summary>
        /// Gibt den Schlssel der Daten, auf die sich die Sperre bezieht, zurck.
        /// </summary>
        public string Key
        {
            get { return _key; }            
        }
                
        /// <summary>
        /// Gibt den zurck oder legt fest, ob die Sperranforderung erfolgreich war.
        /// </summary>
        public bool Success
        {
            get { return _success; }
            set { _success = value; }
        }

        /// <summary>
        /// Gibt den Zeitstempel der Sperre zurck.
        /// </summary>
        public DateTime Timestamp
        {
            get { return _timestamp; }            
        }
        
        /// <summary>
        /// Gibt den eindeutigen Schlssel der Sperre zurck.
        /// </summary>
        public Guid LockID
        {
            get { return _lockID; }            
        }

        /// <summary>
        /// Gibt den Namen des Benutzers der Sperre zurck.
        /// </summary>
        public string UserName
        {
            get { return _userName; }            
        }

        /// <summary>
        /// Gibt die Nachricht vom Applikationsserver zurck oder legt sie fest.
        /// </summary>
        public string Message
        {
            get { return _message; }
            set { _message = value; }
        }

        #endregion
    }
}
