using System;
using System.Collections.Generic;
using System.Text;
using System.Globalization;
using System.Diagnostics;
using System.Runtime.Remoting.Messaging;

namespace Rainbird.AppServer.API
{
    /// <summary>
    /// Container fr Daten, die an den Aufrufkontext angehngt werden.
    /// </summary>
    [Serializable]
    public class LogicalCallContextData : ILogicalThreadAffinative
    {
        // Sitzungsschlssel
        private Guid _sessionID = Guid.Empty;

        // Server-URL
        private string _serverURL = string.Empty;

        // Kultureinstellungen
        private CultureInfo _culture = null;
        private CultureInfo _cultureUI = null;

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="serverURL">URL zum Applikationsserver (z.B.: "tcp://localhost:6060/NTierExample/")</param>
        /// <param name="sessionID">Sitzungsschlssel</param>
        /// <param name="culture">Kultur</param>
        /// <param name="cultureUI">Kultur der Benutzeroberflche</param>
        public LogicalCallContextData(string serverURL, Guid sessionID, CultureInfo culture,CultureInfo cultureUI)
        {
            Debug.Assert(!string.IsNullOrEmpty(serverURL), "!string.IsNullOrEmpty(serverURL)");
            Debug.Assert(sessionID != null && sessionID != Guid.Empty, "sessionID!=null && sessionID!=Guid.Empty");
            Debug.Assert(culture != null, "culture != null");
            Debug.Assert(cultureUI != null, "cultureUI!=null");

            // Werte bernehmen
            _serverURL = serverURL;
            _sessionID = sessionID;
            _culture = culture;
            _cultureUI = cultureUI;
        }

        /// <summary>
        /// Gibt den Sitzungsschlssel des Aufrufkontextes zurck.
        /// </summary>
        public Guid SessionID
        {
            get { return _sessionID; }
        }

        /// <summary>
        /// Gibt den URL des Applikationsservers zurck.
        /// </summary>
        public string ServerURL
        {
            get { return _serverURL; }
        }

        /// <summary>
        /// Gibt die Kultureinstellung zurck.
        /// </summary>
        public CultureInfo Culture
        {
            get { return _culture; }
        }

        /// <summary>
        /// Gibt die Kultureinstellung der Benutzeroberflche zurck.
        /// </summary>
        public CultureInfo CultureUI
        {
            get { return _cultureUI; }
        }
    }
}
