using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Serialization;

namespace Rainbird.AppServer.API
{
    /// <summary>
    /// Beschreibt eine Sicherheitsrolle.
    /// </summary>
    [Serializable]
    [XmlRoot(ElementName="role",Namespace="urn:Rainbird.AppServer.API.2007",IsNullable=true)]
    public class SecurityRole
    {
        #region Deklarationen

        // Rollenname
        private string _roleName = string.Empty;

        // Zugewiesene Windows-Gruppe
        private string _mappedWindowsGroup = string.Empty;

        #endregion

        #region Konstruktoren

        /// <summary>
        /// Standardkonstruktor.
        /// </summary>
        public SecurityRole() { }

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        public SecurityRole(string roleName)
        { 
            // Wenn ein leerer Name bergeben wird ...
            if (string.IsNullOrEmpty(roleName))
                // Ausnahme werfen
                throw new ArgumentNullException();

            // Rollenname bernehmen
            _roleName = roleName;
        }

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <param name="mappedWindowsGroup">Verknpfte Windows-Gruppe</param>
        public SecurityRole(string roleName, string mappedWindowsGroup)
        { 
            // Felder befllen
            _roleName = roleName;
            _mappedWindowsGroup = mappedWindowsGroup;
        }

        #endregion

        #region Eigenschaften

        /// <summary>
        /// Gibt den Rollennamen zurck oder legt ihn fest.
        /// </summary>
        [XmlAttribute("name")]
        public string RoleName
        {
            get { return _roleName; }
            set { _roleName = value; }
        }

        /// <summary>
        /// Gibt die zugewiesene Windows-Gruppe zurck oder legt sie fest.
        /// </summary> 
        [XmlAttribute("windowsgroup")]
        public string MappedWindowsGroup
        {
            get { return _mappedWindowsGroup; }
            set { _mappedWindowsGroup = value; }
        }

        #endregion
    }
}
