using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.Remoting;
using System.Runtime.Remoting.Activation;
using System.Configuration;
using System.IO;
using System.Reflection;
using System.Diagnostics;
using System.ServiceProcess;

namespace Rainbird.AppServer
{
    /// <summary>
    /// Applikationsserver-Kern.
    /// </summary>
    class Core
    {
        // Ablaufverfolgungsobjekt
        private static TraceSource _traceSource = null;
                
        /// <summary>
        /// Eintrittsfunktion.
        /// </summary>
        /// <param name="args">Befehlszeilenargumente</param>
        static void Main(string[] args)
        {
            // Ablaufverfolgungsobjekt erzeugen
            _traceSource = new TraceSource("Core");

            // Daten ber die ausfhrende Assembly abrufen
            Assembly currentAssembly = Assembly.GetExecutingAssembly();

            _traceSource.TraceEvent(TraceEventType.Information, 1000, "-----------------------------------------");
            _traceSource.TraceEvent(TraceEventType.Information, 1000, "Rainbirds Application Server");
            _traceSource.TraceEvent(TraceEventType.Information, 1000, "Version " + currentAssembly.GetName().Version.ToString());
            _traceSource.TraceEvent(TraceEventType.Information, 1000, "Written in December 2007 by Hagen Siegel");
            _traceSource.TraceEvent(TraceEventType.Information, 1000, "-----------------------------------------");

            _traceSource.TraceEvent(TraceEventType.Information, 1801, "Checking Distributed Transaction Coordinator ...");

            // Dienststeuerung fr den Distributed Transaction Coordinator erzeugen
            ServiceController controller = new ServiceController("MSDTC");

            // Wenn der Distributed Transaction Coordinator nicht gestartet ist ...
            if (controller.Status != ServiceControllerStatus.Running)
            {
                _traceSource.TraceEvent(TraceEventType.Information, 1802, "-> Not running!");

                try
                {
                    _traceSource.TraceEvent(TraceEventType.Information, 1803, "Try to start service 'Distributed Transaction Coordinator' ...");

                    // Distributed Transaction Coordinator starten
                    controller.Start();

                    _traceSource.TraceEvent(TraceEventType.Information, 1804, "-> Success");
                }
                catch (Exception ex)
                {
                    _traceSource.TraceEvent(TraceEventType.Critical, 3801, "-> Failed");
                    _traceSource.TraceEvent(TraceEventType.Critical, 3801, ex.Message);

                    // Auf Tastendruck warten
                    Console.ReadLine();

                    // Anwendung beenden
                    return;
                }
            }    
            else
                _traceSource.TraceEvent(TraceEventType.Information, 1805, "-> OK");

            // Pfad zur Konfigurationsdatei erzeugen
            string configFile = currentAssembly.Location + ".config";

            Debug.Assert(File.Exists(configFile), @"File.Exists(configFile)");

            // Remoting-Infrastruktur konfigurieren
            RemotingConfiguration.Configure(configFile, true);

            _traceSource.TraceEvent(TraceEventType.Information,1101,"Publish service: Rainbird.AppServer.API.ISecurityService");

            // Sicherheitsdienst verffentlichen
            RemotingServices.Marshal(SecurityService.Instance, "Rainbird.AppServer.API.ISecurityService");

            _traceSource.TraceEvent(TraceEventType.Information, 1102, "Publish service: Rainbird.AppServer.API.ILockingService");

            // Sperrungsdienst verffentlichen
            RemotingServices.Marshal(Locking.LockingService.Instance, "Rainbird.AppServer.API.ILockingService");

            _traceSource.TraceEvent(TraceEventType.Information, 1103, "Initializing business services ...");

            // Alle Dienste durchlaufen
            foreach (WellKnownServiceTypeEntry serviceEntry in RemotingConfiguration.GetRegisteredWellKnownServiceTypes())
            {
                _traceSource.TraceEvent(TraceEventType.Information, 1104, "-> {0}",serviceEntry.ObjectUri);
            }            
            _traceSource.TraceEvent(TraceEventType.Verbose,1001,"Ready");

            // Auf Eingabe warten            
            Console.ReadLine();
        }
    }
}
