using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Serialization;

namespace Rainbird.AppServer
{
    /// <summary>
    /// Beschreibt eine Sicherheitsrolle.
    /// </summary>
    [Serializable]
    [XmlRoot(ElementName = "role", Namespace = "urn:Rainbird.AppServer.Role.2007", IsNullable = true)]
    public class Role
    {
        #region Deklarationen

        // Rollenname
        private string _roleName = string.Empty;

        // Zugewiesene Windows-Gruppe
        private string _windowsGroup = string.Empty;

        #endregion

        #region Konstruktoren

        /// <summary>
        /// Standardkonstruktor.
        /// </summary>
        public Role() { }

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        public Role(string roleName)
        {
            // Wenn ein leerer Name bergeben wird ...
            if (string.IsNullOrEmpty(roleName))
                // Ausnahme werfen
                throw new ArgumentNullException();

            // Rollenname bernehmen
            _roleName = roleName;
        }

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <param name="windowsGroup">Verknpfte Windows-Gruppe</param>
        public Role(string roleName, string windowsGroup)
        {
            // Felder befllen
            _roleName = roleName;
            _windowsGroup = windowsGroup;
        }

        #endregion

        #region Eigenschaften

        /// <summary>
        /// Gibt den Rollennamen zurck oder legt ihn fest.
        /// </summary>
        [XmlAttribute("name")]
        public string RoleName
        {
            get { return _roleName; }
            set { _roleName = value; }
        }

        /// <summary>
        /// Gibt die zugewiesene Windows-Gruppe zurck oder legt sie fest.
        /// </summary> 
        [XmlAttribute("windowsgroup")]
        public string WindowsGroup
        {
            get { return _windowsGroup; }
            set { _windowsGroup = value; }
        }

        #endregion
    }
}
