using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Serialization;

namespace Rainbird.AppServer
{
    /// <summary>
    /// Beschreibt einen Speicher fr mehrere Sicherheitsrollen.
    /// </summary>
    [Serializable]
    [XmlRoot(ElementName="rolestore",Namespace="urn:Rainbird.AppServer.RoleStore.2007",IsNullable=true)]
    public class RoleStore
    {
        // Rollen-Auflistung
        private List<Role> _roles = null;

        /// <summary>
        /// Standardkonstruktor.
        /// </summary>
        public RoleStore()
        { 
            // Auflistung erzeugen
            _roles = new List<Role>();
        }

        /// <summary>
        /// Gibt die Rollen-Auflistung zurck oder legt sie fest.
        /// </summary>
        [XmlArray("roles")]
        [XmlArrayItem("role")]
        public List<Role> Roles
        {
            get { return _roles; }
            set { _roles = value; }
        }

        /// <summary>
        /// Gibt zurck, ob eine bestimmte Rolle existiert, oder nicht.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <returns>Prfergebnis</returns>
        public bool ExistRole(string roleName)
        { 
            // Alle Rollen durchlaufen
            foreach (Role role in _roles)
            { 
                // Wenn die Rolle gefunden wurde ...
                if (role.RoleName == roleName)
                    // Wahr zurckgeben
                    return true;
            }
            // Falsch zurckgeben
            return false;
        }

        /// <summary>
        /// Gibt eien bestimmte Rolle aus dem Rollenspeicher anhand ihres Namens zurck.
        /// </summary>
        /// <param name="roleName">Rollenname</param>
        /// <returns>Rolle</returns>
        public Role GetRoleByName(string roleName)
        {
            // Alle Rollen durchlaufen
            foreach (Role role in _roles)
            {
                // Wenn die Rolle gefunden wurde ...
                if (role.RoleName == roleName)
                    // Rolle zurckgeben
                    return role;
            }
            // Ausnahme werfen
            throw new ApplicationException(string.Format(LanguageResource.UnknownRole, roleName));
        }
    }
}
