using System;
using System.Collections.Generic;
using System.Text;
using System.Globalization;
using System.Security.Principal;

namespace Rainbird.AppServer
{
    /// <summary>
    /// Beschreibt eine Sitzung.
    /// </summary>
    [Serializable]
    internal class Session
    {
        #region Deklarationen

        // Sitzungsschlssel
        private Guid _sessionID = Guid.Empty;
                
        // Identitt des Benutzers
        private WindowsIdentity _identity = null;

        // Zeitstempel der Sitzung
        private DateTime _timestamp = DateTime.MinValue;

        #endregion

        #region Konstruktoren

        /// <summary>
        /// Konstruktor.
        /// </summary>
        /// <param name="identity">Benutzer-Identitt</param>
        /// <param name="timestamp">Zeitstempel</param>
        internal Session(WindowsIdentity identity, DateTime timestamp)
        { 
            // Eindeutigen Sitzungsschlssel vergeben
            _sessionID = Guid.NewGuid();

            // Werte bernehmen
            _identity = identity;
            _timestamp = timestamp;            
        }

        #endregion

        #region Erneuerung

        /// <summary>
        /// Erneuert die Sitzung.
        /// </summary>
        internal void Renew()
        { 
            // Neuen Zeitstempel setzen
            _timestamp = DateTime.Now;
        }

        #endregion

        #region Eigenschaften

        /// <summary>
        /// Gibt den Sitzungsschlssel zurck.
        /// </summary>
        internal Guid SessionID
        {
            get { return _sessionID; }            
        }
        
        /// <summary>
        /// Gibt die Identitt des Benutzers der Sitzung zurck.
        /// </summary>
        internal WindowsIdentity Identity
        {
            get { return _identity; }
        } 

        /// <summary>
        /// Gibt den Zeitstempel der Sitzung zurk.
        /// </summary>
        internal DateTime Timestamp
        {
            get { return _timestamp; }
        }

        #endregion
    }
}
