using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Transactions;

namespace Rainbird.Examples.NTier.ArticleMaster.Contracts
{
    /// <summary>
    /// Schnittstelle des Geschftsdienstes zur Verwaltung des Artikelstamms.
    /// </summary>
    public interface IArticleMasterService
    {
        /// <summary>
        /// Gibt ein bestimmtes Produkt anhand seines Produktschlssels zurck.
        /// </summary>
        /// <param name="productID">Eindeutiger Produktschlssel</param>
        /// <returns>Tabelle mit Produktdatensatz</returns>
        ArticleMasterDataSet.ProductsDataTable GetProduct(Guid productID);

        /// <summary>
        /// Gibt ein bestimmtes Produkt anhand seiner Produktnummer zurck.
        /// </summary>
        /// <param name="productNumber">Produktnummer</param>
        /// <returns>Tabelle mit Produktdatensatz</returns>
        ArticleMasterDataSet.ProductsDataTable GetProduct(string productNumber);

        /// <summary>
        /// Sucht Produkte anhand der Produktnummer oder eines Teils davon.
        /// </summary>
        /// <param name="pattern">Suchmuster (% = Joker)</param>
        /// <returns>Trefferliste
        /// <remarks>
        /// Enthlt folgende Spalten:
        /// 
        /// ProductID
        /// ProductNumber
        /// ProductName
        /// </remarks>
        /// </returns>
        DataTable FindProductsByNumber(string pattern);

        /// <summary>
        /// Sucht Produkte anhand des Produktnamens oder eines Teils davon.
        /// </summary>
        /// <param name="pattern">Suchmuster (% = Joker)</param>
        /// <returns>Trefferliste
        /// <remarks>
        /// Enthlt folgende Spalten:
        /// 
        /// ProductID
        /// ProductNumber
        /// ProductName
        /// </remarks>
        /// </returns>
        DataTable FindProductsByName(string pattern);

        /// <summary>
        /// Speichert Produkt-Datenstze innerhlb einer Transaktion.
        /// </summary>
        /// <param name="products">Produktdatenstze</param>
        /// <param name="transaction">Transaktion (Optional)</param>
        /// <returns>Tabelle mit gespeicherten Produktdatenstzen</returns>
        ArticleMasterDataSet.ProductsDataTable SaveProducts(ArticleMasterDataSet.ProductsDataTable products, Transaction transaction);
    }
}
