using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Security;
using System.Transactions;
using Rainbird.AppServer.API;
using Rainbird.Examples.NTier.ArticleMaster.Contracts;
using Rainbird.Examples.NTier.ArticleMaster.BusinessLogic;

namespace Rainbird.Examples.NTier.ArticleMaster.Services
{
    /// <summary>
    /// Geschftsdienst "Artikelstammverwaltung".
    /// </summary>
    public class ArticleMasterService : MarshalByRefObject, IArticleMasterService
    {
        #region IArticleMasterService Member

        /// <summary>
        /// Gibt ein bestimmtes Produkt anhand seines Produktschlssels zurck.
        /// </summary>
        /// <param name="productID">Eindeutiger Produktschlssel</param>
        /// <returns>Tabelle mit Produktdatensatz</returns>
        public ArticleMasterDataSet.ProductsDataTable GetProduct(Guid productID)
        {
            // Lndereinstellungen vom Aufrufer annehmen
            ApplicationServer.AssumeCultureFromSession();

            // Wenn der Aufrufer in der Rolle "Product Reader" ist ...
            if (ApplicationServer.IsInRole("Product Reader"))
            {
                // Aufruf an Geschftslogik delegieren
                return new ProductManager().GetProduct(productID);
            }
            else
                // Ausnahme werfen
                throw new SecurityException(ApplicationServer.LocalizedAccessDeniedMessage);
        }

        /// <summary>
        /// Gibt ein bestimmtes Produkt anhand seiner Produktnummer zurck.
        /// </summary>
        /// <param name="productNumber">Produktnummer</param>
        /// <returns>Tabelle mit Produktdatensatz</returns>
        public ArticleMasterDataSet.ProductsDataTable GetProduct(string productNumber)
        {
            // Lndereinstellungen vom Aufrufer annehmen
            ApplicationServer.AssumeCultureFromSession();

            // Wenn der Aufrufer in der Rolle "Product Reader" ist ...
            if (ApplicationServer.IsInRole("Product Reader"))
            {
                // Aufruf an Geschftslogik delegieren
                return new ProductManager().GetProduct(productNumber);
            }
            else
                // Ausnahme werfen
                throw new SecurityException(ApplicationServer.LocalizedAccessDeniedMessage);
        }

        /// <summary>
        /// Sucht Produkte anhand der Produktnummer oder eines Teils davon.
        /// </summary>
        /// <param name="pattern">Suchmuster (% = Joker)</param>
        /// <returns>Trefferliste
        /// <remarks>
        /// Enthlt folgende Spalten:
        /// 
        /// ProductID
        /// ProductNumber
        /// ProductName
        /// </remarks>
        /// </returns>
        public DataTable FindProductsByNumber(string pattern)
        {
            // Lndereinstellungen vom Aufrufer annehmen
            ApplicationServer.AssumeCultureFromSession();

            // Wenn der Aufrufer in der Rolle "Product Reader" ist ...
            if (ApplicationServer.IsInRole("Product Reader"))
            {
                // Aufruf an Geschftslogik delegieren
                return new ProductManager().FindProductsByNumber(pattern);
            }
            else
                // Ausnahme werfen
                throw new SecurityException(ApplicationServer.LocalizedAccessDeniedMessage);
        }

        /// <summary>
        /// Sucht Produkte anhand des Produktnamens oder eines Teils davon.
        /// </summary>
        /// <param name="pattern">Suchmuster (% = Joker)</param>
        /// <returns>Trefferliste
        /// <remarks>
        /// Enthlt folgende Spalten:
        /// 
        /// ProductID
        /// ProductNumber
        /// ProductName
        /// </remarks>
        /// </returns>
        public DataTable FindProductsByName(string pattern)
        {
            // Lndereinstellungen vom Aufrufer annehmen
            ApplicationServer.AssumeCultureFromSession();

            // Wenn der Aufrufer in der Rolle "Product Reader" ist ...
            if (ApplicationServer.IsInRole("Product Reader"))
            {
                // Aufruf an Geschftslogik delegieren
                return new ProductManager().FindProductsByName(pattern);
            }
            else
                // Ausnahme werfen
                throw new SecurityException(ApplicationServer.LocalizedAccessDeniedMessage);
        }

        /// <summary>
        /// Speichert Produkt-Datenstze innerhlb einer Transaktion.
        /// </summary>
        /// <param name="products">Produktdatenstze</param>
        /// <param name="transaction">Transaktion (Optional)</param>
        /// <returns>Tabelle mit gespeicherten Produktdatenstzen</returns>
        public ArticleMasterDataSet.ProductsDataTable SaveProducts(ArticleMasterDataSet.ProductsDataTable products, Transaction transaction)
        {
            // Lndereinstellungen vom Aufrufer annehmen
            ApplicationServer.AssumeCultureFromSession();

            // Wenn der Aufrufer in der Rolle "Product Writer" ist ...
            if (ApplicationServer.IsInRole("Product Writer"))
            {
                // Aufruf an Geschftslogik delegieren
                return new ProductManager().SaveProducts(products,transaction);
            }
            else
                // Ausnahme werfen
                throw new SecurityException(ApplicationServer.LocalizedAccessDeniedMessage);
        }

        #endregion
    }
}
