using System;
using System.Collections.Generic;
using System.Text;
using System.Transactions;
using System.Data;

namespace Rainbird.Examples.NTier.Inventory.Contracts
{
    /// <summary>
    /// Schnittstelle des Lagerverwaltungs-Geschftsdienstes.
    /// </summary>
    public interface IInventoryService
    {
        /// <summary>
        /// Gibt alle angelegten Lager zurck.
        /// </summary>
        /// <returns>Alle Lager (als Tabelle)</returns>
        InventoryDataSet.RepositoriesDataTable GetAllRepositories();

        /// <summary>
        /// Gibt den Namen eines bestimmten Lagers zurck.
        /// </summary>
        /// <param name="repositoryID">Lagerschlssel</param>
        /// <returns>Name</returns>
        string GetRepositoryName(Guid repositoryID);

        /// <summary>
        /// Sucht Lger, die keine Bestnde eines bestimmten Produkts enthalten.
        /// <remarks>
        /// Die Ergebnistabelle enthlt folgende Spalten:
        /// 
        /// RepositoryID
        /// Name
        /// </remarks>
        /// </summary>
        /// <param name="productID">Produktschlssel</param>
        /// <returns>Tabelle mit Lagerinformationen</returns>
        DataTable FindRepositoriesWithoutProductOnStock(Guid productID);

        /// <summary>
        /// Speichert Lager-Datenstze innerhalb einer Transaktion.
        /// </summary>
        /// <param name="repositories">Lagerdatenstze</param>
        /// <param name="transaction">Transaktion (Optional)</param>
        /// <returns>Tabelle mit gespeicherten Lager-Datenstzen</returns>
        InventoryDataSet.RepositoriesDataTable SaveRepositories(InventoryDataSet.RepositoriesDataTable repositories, Transaction transaction);

        /// <summary>
        /// Gibt alle Bestnde eines bestimmten Lagers zurck.
        /// </summary>
        /// <param name="repositoryID">Lagerschlssel</param>
        /// <returns>Tabelle mit Bestandsdatenstzen</returns>
        InventoryDataSet.StocksDataTable GetStocksByRepositoryID(Guid repositoryID);

        /// <summary>
        /// Gibt einen bestimmten Lagerbestand zurck.
        /// </summary>
        /// <param name="stockID">Bestandsschlssel</param>
        /// <returns>Tabelle mit Bestandsdatensatz</returns>
        InventoryDataSet.StocksDataTable GetStock(Guid stockID);

        /// <summary>
        /// Gibt alle Lagerbestnde eines bestimmten Produkts zurck.
        /// </summary>
        /// <param name="productID">Produktschlssel</param>
        /// <returns>Tabelle mit Bestandsdatenstzen</returns>
        InventoryDataSet.StocksDataTable GetProductStocks(Guid productID);

        /// <summary>
        /// Prft, ob ein Bestand fr ein bestimmtes Produkt bereits in einem bestimmten Lager existiert.
        /// </summary>
        /// <param name="repositoryID">Lagerschlssel</param>
        /// <param name="productID">Produktschlssel</param>
        /// <returns>Prfergebnis</returns>
        bool ExistStock(Guid repositoryID, Guid productID);

        /// <summary>
        /// Legt einen neuen Lagerbestand an.
        /// </summary>
        /// <param name="repositoryID">Lagerschlssel</param>
        /// <param name="productID">Produktschlssel</param>
        /// <param name="binLocation">Lagerort</param>
        /// <param name="estimatedStock">Soll-Bestand</param>
        /// <param name="reorderPoint">Meldebestand</param>
        /// <param name="transaction">Transaktionsobjekt (Optional)</param>
        /// <returns>Bestandsdatensatz</returns>
        InventoryDataSet.StocksDataTable CreateStock(Guid repositoryID, Guid productID, string binLocation, decimal estimatedStock, decimal reorderPoint, Transaction transaction);

        /// <summary>
        /// Aktualisiert Bestandsparameter (Meldebestand etc.).
        /// </summary>
        /// <param name="stockID">Bestandsschlssel</param>
        /// <param name="binLocation">Lagerort</param>
        /// <param name="estimatedStock">Soll-Bestand</param>
        /// <param name="reorderPoint">Meldebestand</param>
        /// <param name="transaction">Transaktionsobjekt (Optional)</param>
        /// <returns>Aktualisierter Bestandsdatensatz</returns>
        InventoryDataSet.StocksDataTable UpdateStockParameters(Guid stockID, string binLocation, decimal estimatedStock, decimal reorderPoint, Transaction transaction);

        /// <summary>
        /// Fhrt eine Lagerbestandsbuchung durch.
        /// </summary>
        /// <param name="stockID">Bestandsschlssel</param>
        /// <param name="quantity">Menge</param>
        /// <param name="transaction">Transaktionsobjekt (Optional)</param>
        /// <returns>Neuer Ist-Bestand</returns>
        decimal Book(Guid stockID, decimal quantity, Transaction transaction);
    }
}
